@@ -6,9 +6,13 @@ Account
 import deepcrawl
 from deepcrawl.utils import ImmutableAttributesMixin, safe_string_to_datetime
 
-account_mutable_fields = (
+
+account_extra_fields = (
     "id",
     "projects",
+)
+
+account_mutable_fields = account_extra_fields + (
     'active',
     'address_city',
     'address_state',
@@ -144,6 +148,28 @@ class DeepCrawlAccount(ImmutableAttributesMixin):
 
         super(DeepCrawlAccount, self).__init__()
 
+    def __repr__(self):
+        return f"[{self.id}] {self.name}"
+
+    def __str__(self):
+        return f"[{self.id}] {self.name}"
+
+    @property
+    def to_dict_mutable_fields(self):
+        """
+        :return: dictionary with the mutable fields
+        :rtype: dict
+        """
+        return {x: getattr(self, x, None) for x in account_mutable_fields}
+
+    @property
+    def to_dict_immutable_fields(self):
+        """
+        :return: dictionary with the immutable fields
+        :rtype: dict
+        """
+        return {x: getattr(self, x, None) for x in account_immutable_fields}
+
     def load_projects(self, connection=None, filters=None, **kwargs):
         """Loads projects into current instance
 
@@ -177,7 +203,7 @@ class DeepCrawlAccount(ImmutableAttributesMixin):
         * if the instance id is not None then the account will be updated
 
         >>> self.save()
-        NotImplementedError
+        [0] DeepCrawlAccount
 
         :param connection: connection
         :type connection: deepcrawl.DeepCrawlConnection
@@ -194,7 +220,7 @@ class DeepCrawlAccount(ImmutableAttributesMixin):
         """Makes a call to DeepCrawl in order to refresh the current instance.
 
         >>> self.refresh()
-        <deepcrawl.accounts.account.DeepCrawlAccount at 0x108a20600>
+        [0] DeepCrawlAccount
 
         :param connection: connection
         :type connection: deepcrawl.DeepCrawlConnection
@@ -211,7 +237,7 @@ class DeepCrawlAccount(ImmutableAttributesMixin):
         """Updates an instance with account_settings
 
         >>> self.update(account_settings)
-        <deepcrawl.accounts.account.DeepCrawlAccount at 0x108a20600>
+        [0] DeepCrawlAccount
 
         :param account_settings: dictionary with the new configuration
         :type account_settings: dict
@@ -227,35 +253,74 @@ class DeepCrawlAccount(ImmutableAttributesMixin):
             setattr(self, key, getattr(account, key))
         return self
 
-    def delete(self, connection=None):
-        """Delete current instance
-
-        >>> self.delete()
-        NotImplementedError
-
-        :param connection: connection
-        :type connection: deepcrawl.DeepCrawlConnection
-        :return: Error
-        """
-        response = connection.delete_account(self.id)
-        return response
-
     """
     PROJECTS
     """
     def create_project(self, project_settings, connection=None):
+        """Create project.
+        Project settings argument can be dict or a ProjectSettings instance.
+
+        >>> self.create_project(project_settings)
+        [0 1] www.test.com Project
+
+        :param project_settings: project configuration
+        :type project_settings: dict or ProjectSettings
+        :param connection: connection
+        :type connection: deepcrawl.DeepCrawlConnection
+        :return: Project instance
+        :rtype: DeepCrawlProject
+        """
         connection = connection or deepcrawl.DeepCrawlConnection.get_instance()
         return connection.create_project(self.id, project_settings)
 
     def get_project(self, project_id, connection=None):
+        """Get Project
+
+        >>> self.get_project(1)
+        [0 1] www.test.com Project
+
+        :param project_id: project id
+        :type project_id: int
+        :param connection: connection
+        :type connection: deepcrawl.DeepCrawlConnection
+        :return: Requested project
+        :rtype: DeepCrawlProject
+        """
         connection = connection or deepcrawl.DeepCrawlConnection.get_instance()
         return connection.get_project(self.id, project_id)
 
     def update_project_settings(self, project_id, settings, connection=None):
+        """Update the project settings.
+        Settings argument can be dict or a ProjectSettings instance.
+
+        >>> self.update_project_settings(1, settings)
+        [0 1] www.test.com Project
+
+        :param project_id: project id
+        :type project_id: int
+        :param settings: new settings configuration
+        :type settings: dict or ProjectSettings
+        :param connection: connection
+        :type connection: deepcrawl.DeepCrawlConnection
+        :return: Updated project
+        :rtype: DeepCrawlProject
+        """
         connection = connection or deepcrawl.DeepCrawlConnection.get_instance()
         return connection.update_project_settings(self.id, project_id, settings)
 
     def delete_project(self, project_id, connection=None):
+        """Delete project
+
+        >>> response = self.delete_project(1)
+        >>> response.status_code
+        204
+
+        :param project_id: project id
+        :type project_id: int
+        :param connection: connection
+        :type connection: deepcrawl.DeepCrawlConnection
+        :return: HTTP 204 No Content
+        """
         connection = connection or deepcrawl.DeepCrawlConnection.get_instance()
         return connection.delete_project(self.id, project_id)
 
