@@ -49,7 +49,7 @@ class AccountConnection(ApiConnection):
             }
 
         >>> connection.create_account(account_data)
-        <deepcrawl.accounts.account.DeepCrawlAccount at 0x108a20600>
+        [0] DeepCrawlAccount
 
         :param account_data: account configuration
         :type account_data: dict
@@ -64,7 +64,7 @@ class AccountConnection(ApiConnection):
         """Get account
 
         >>> connection.get_account(0)
-        <deepcrawl.accounts.account.DeepCrawlAccount at 0x108a20600>
+        [0] DeepCrawlAccount
 
         :param account_id: account id
         :type account_id: int
@@ -79,7 +79,7 @@ class AccountConnection(ApiConnection):
         """Update account
 
         >>> connection.update_account("0", account_data)
-        <deepcrawl.accounts.account.DeepCrawlAccount at 0x108a20600>
+        [0] DeepCrawlAccount
 
         :param account_id: account id
         :type account_id: int
@@ -92,27 +92,12 @@ class AccountConnection(ApiConnection):
         response = self.dc_request(url=endpoint_url, method='patch', json=account_data)
         return DeepCrawlAccount(account_data=response.json())
 
-    def delete_account(self, account_id):
-        """Delete account
-
-        >>> connection.delete_account(0)
-        NotImplementedError
-
-        :param account_id: account id
-        :type account_id: int
-        :return: NotImplementedError
-        :rtype: Error
-        """
-        raise NotImplementedError
-        # endpoint_url = get_api_endpoint(endpoint='account', account_id=account_id)
-        # return self.dc_request(url=endpoint_url, method='delete')
-
     def get_accounts(self, filters=None, **kwargs):
         """Get all accounts associated with the credentials used to generate the connection
 
         >>> connection.get_accounts()
-        [<deepcrawl.accounts.account.DeepCrawlAccount at 0x108a20600>,
-        <deepcrawl.accounts.account.DeepCrawlAccount at 0x108a20600>]
+        [[0] DeepCrawlAccount,
+        [1] DeepCrawlAccount]
 
         :param filters: filters
         :type filters: dict
@@ -130,5 +115,3 @@ class AccountConnection(ApiConnection):
                 DeepCrawlAccount(account_data=account)
             )
         return list_of_accounts
-
-    # TODO Add methods for project interactions
